==> wls-plugin-1.2.2.jar: com/xebialabs/deployit/plugin/wls/step/create-maximum-threads-constraint.py <==
#
# Copyright (c) 2010 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to  (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys
import os
import time as ptime

scriptname = sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)
name = sys.argv.pop(0)
domain = sys.argv.pop(0)
targetName = sys.argv.pop(0)
threadcount = int(sys.argv.pop(0))
notes = sys.argv.pop(0)

#====================================#
# Create Maximum Threads Constraint  #
#====================================#
def createMaximumThreadsConstraint(name, domainName, targetname, threadcount, notes):
  log('Create maximum thread constraints '+name)
  targetArray = getClusterServerTargetArray(targetname)
  cd('/SelfTuning/' + domainName + '/MaxThreadsConstraints')
  cmo.createMaxThreadsConstraint(name)
  cd('/SelfTuning/' + domainName + '/MaxThreadsConstraints/' + name)
  set('Count', threadcount)
  set('Notes', notes) 
  set('Targets', targetArray)
  return
  
#=====================================#
# Get ClustServer Target Array        #
#=====================================#
def getClusterServerTargetArray(targetlist):
    objectArray=[];
    targets=targetlist.split( "," )
    for target in targets:
        bean=getMBean( '/Servers/'+target )
        if bean != None :
            objectArray.append( ObjectName('com.bea:Name=' + bean.getName() + ',Type='+bean.getType()) )
        bean=getMBean( '/Clusters/'+target )
        if bean != None :
            objectArray.append( ObjectName('com.bea:Name=' + bean.getName() + ',Type='+bean.getType()) )
    if objectArray :
        targetArray = jarray.array(objectArray, ObjectName)
    else :
        raise ValueError('Not targets found for '+targetlist )             
    return targetArray

#==============================#
# Logging method               #
#==============================#
def log(msg, level="info"):
    print ptime.strftime("%H:%M:%S", ptime.localtime()) + " <" + level + "> " + msg
    return
    
    
#==============================#
# Entry Point                  #
#==============================#
connect(user, password, url)
edit()
startEdit()
createMaximumThreadsConstraint(name, domain, targetName, threadcount, notes)
save()
disconnect('true')
exit('y')

==> wls-plugin-1.4.1.jar: com/xebialabs/deployit/plugin/wls/step/create-maximum-threads-constraint.py <==
#
# Copyright (c) 2008-2011 XebiaLabs B.V. All rights reserved.
#
# Your use of XebiaLabs Software and Documentation is subject to the Personal
# License Agreement.
#
# http://www.xebialabs.com/deployit-personal-edition-license-agreement
#
# You are granted a personal license (i) to use the Software for your own
# personal purposes which may be used in a production environment and/or (ii)
# to use the Documentation to develop your own plugins to the Software.
# "Documentation" means the how to's and instructions (instruction videos)
# provided with the Software and/or available on the XebiaLabs website or other
# websites as well as the provided API documentation, tutorial and access to
# the source code of the XebiaLabs plugins. You agree not to (i) lease, rent
# or sublicense the Software or Documentation to any third party, or otherwise
# use it except as permitted in this agreement; (ii) reverse engineer,
# decompile, disassemble, or otherwise attempt to determine source code or
# protocols from the Software, and/or to (iii) copy the Software or
# Documentation (which includes the source code of the XebiaLabs plugins). You
# shall not create or attempt to create any derivative works from the Software
# except and only to the extent permitted by law. You will preserve XebiaLabs'
# copyright and legal notices on the Software and Documentation. XebiaLabs
# retains all rights not expressly granted to You in the Personal License
# Agreement.
#

import sys
import os
import time as ptime

scriptname = sys.argv.pop(0)
user = sys.argv.pop(0)
password = sys.argv.pop(0)
url = sys.argv.pop(0)
name = sys.argv.pop(0)
domain = sys.argv.pop(0)
targetName = sys.argv.pop(0)
threadcount = int(sys.argv.pop(0))
notes = sys.argv.pop(0)

#====================================#
# Create Maximum Threads Constraint  #
#====================================#
def createMaximumThreadsConstraint(name, domainName, targetname, threadcount, notes):
  print "Create maximum thread constraints " + name
  targetArray = getClusterServerTargetArray(targetname)
  cd('/SelfTuning/' + domainName + '/MaxThreadsConstraints')
  cmo.createMaxThreadsConstraint(name)
  cd('/SelfTuning/' + domainName + '/MaxThreadsConstraints/' + name)
  set('Count', threadcount)
  set('Notes', notes) 
  set('Targets', targetArray)
  return
  
#=====================================#
# Get ClustServer Target Array        #
#=====================================#
def getClusterServerTargetArray(targetlist):
    objectArray=[];
    targets=targetlist.split( "," )
    for target in targets:
        bean=getMBean( '/Servers/'+target )
        if bean != None :
            objectArray.append( ObjectName('com.bea:Name=' + bean.getName() + ',Type='+bean.getType()) )
        bean=getMBean( '/Clusters/'+target )
        if bean != None :
            objectArray.append( ObjectName('com.bea:Name=' + bean.getName() + ',Type='+bean.getType()) )
    if objectArray :
        targetArray = jarray.array(objectArray, ObjectName)
    else :
        raise ValueError('Not targets found for '+targetlist )             
    return targetArray

#==============================#
# Entry Point                  #
#==============================#
print "Connecting to WebLogic"
connect(user, password, url)
edit()
startEdit()

createMaximumThreadsConstraint(name, domain, targetName, threadcount, notes)

print "Saving configuration"
save()
disconnect('true')
exit('y')
